@@ -33,6 +33,7 @@ WATER_INCHI = "InChI=1S/H2O/h1H2"
 PROTON_INCHI_KEY = "GPRLSGONYQIRFK-UHFFFAOYSA-N"
 WATER_INCHI_KEY = "XLYOFNOQVPJJNP-UHFFFAOYSA-N"
 
+
 from .exceptions import ParseException
 from .models import (
     Compound,
@@ -51,4 +52,8 @@ from .thermodynamic_constants import (
 )
 from .compound_cache import CompoundCache
 from .reaction import Reaction
-from .api import create_compound_cache_from_quilt, DEFAULT_QUILT_PKG
+from .zenodo import ZenodoSettings, DEFAULT_COMPOUND_CACHE_SETTINGS
+from .api import (
+    create_compound_cache_from_zenodo,
+    create_compound_cache_from_sqlite_file,
+)
