@@ -1,3 +1,4 @@
+"""An API module for initializing the cache."""
 # The MIT License (MIT)
 #
 # Copyright (c) 2013 Weizmann Institute of Science.
@@ -26,53 +27,48 @@
 
 import logging
 
-import quilt
-from requests.exceptions import ConnectionError
 from sqlalchemy import create_engine
 
 from .compound_cache import CompoundCache
-
-
-__all__ = ("create_compound_cache_from_quilt", "DEFAULT_QUILT_PKG")
+from .zenodo import (
+    DEFAULT_COMPOUND_CACHE_SETTINGS,
+    ZenodoSettings,
+    get_cached_filepath,
+)
 
 
 logger = logging.getLogger(__name__)
 
-DEFAULT_QUILT_PKG = "equilibrator/cache"
-DEFAULT_QUILT_VERSION = "0.2.4"
 
-
-def create_compound_cache_from_quilt(
-    package: str = DEFAULT_QUILT_PKG,
-    overwrite: bool = True,
-    version: str = DEFAULT_QUILT_VERSION,
-) -> CompoundCache:
+def create_compound_cache_from_sqlite_file(path: str) -> CompoundCache:
     """
-    Initialize a compound cache from a quilt data package.
+    Initialize a compound cache from a local SQLite file.
 
     Parameters
     ----------
-    package : str, optional
-        The quilt data package used to initialize the compound cache.
-    overwrite : bool, optional
-        Re-download the quilt data if a newer version exists (default).
-    version : str, optional
-        The version of the quilt data package.
+    path : str
+        The path to the SQLite file.
 
     """
-    try:
-        logger.info("Fetching eQuilibrator compound cache...")
-        quilt.install(package, version=version, force=overwrite)
-    except ConnectionError:
-        logger.error(
-            "No internet connection available. Attempting to use existing "
-            "compound cache."
-        )
-    except PermissionError:
-        logger.error(
-            "You do not have the necessary filesystem permissions to download "
-            "an update to the quilt data. Attempting to use existing "
-            "compound cache."
-        )
-    cache = quilt.load(package)
-    return CompoundCache(create_engine(f"sqlite:///{cache.compounds()}"))
+    return CompoundCache(create_engine(f"sqlite:///{path}"))
+
+
+def create_compound_cache_from_zenodo(
+    settings: ZenodoSettings = DEFAULT_COMPOUND_CACHE_SETTINGS,
+) -> CompoundCache:
+    """
+    Initialize a compound cache from Zenodo.
+
+    Parameters
+    ----------
+    settings : ZenodoSettings, optional
+        Configuration for the interaction with Zenodo.org.
+
+    Returns
+    -------
+    CompoundCache
+        a compound cache object.
+
+    """
+    path = get_cached_filepath(settings)
+    return create_compound_cache_from_sqlite_file(path)
